fs1
============

.. warning::

  This is an emergency patch for the Climate Impact Lab. Do not use this repository.

We highly recommend that you check out pyfilesystem at https://github.com/PyFilesystem/pyfilesystem2